unit uMepMapSender;

{******************************************************************************
Initial Author   :    Scott Price
Initially Created:    06-Apri-2003
Language         :    Object Pascal
Compiler Version :    Delphi 3.02, 4.03, 5.01, 6.02 (UK)
Copyright        :     Information Technology Sector Limited, 1996-2002

Source Code Constraints:
========================
   Distribution, disclosure or modifications of this source code, outside of
   any licenced agreements with Information Technology Sector Limited, or
   removal of this notice constitutes a breach of any or all license agreements.

Operating Systems Tested On:
============================
   Microsoft Windows(R) 98, First Edition
   Microsoft Windows(R) 2000, Service Pack 2

Design Notes:
=============

VERSION  AUTHOR                DATE/TIME
===============================================================================
$history$
$nokeywords$
===============================================================================
NOTES:
 - The Sender will only connect to an existing memory mapping to transfer its
   data.  It will not create a mem mapping if nothing is waiting to receive.
===============================================================================
TODO:
******************************************************************************}


interface



uses
  { Own Units }
  uMemMapExampleConsts,

  { Borland Standard Units }
{$IFDEF VER140}
  Variants,
{$ENDIF}  
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls;


type
  { TfmMappedMemSender }

  TfmMappedMemSender = class(TForm)
    btnAnotherPressMe: TButton;
    btnSendPressMe: TButton;
    procedure btnSendPressMeClick(Sender: TObject);
  private
    { Private declarations }
    { My memory mapping class dereived from a fairly general definition
      base memory mapping class }
    FMemMapping: uMemMapExampleConsts.TMemMapExample;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    destructor Destroy; override;
  end;


var
  fmMappedMemSender: TfmMappedMemSender;



implementation



{$R *.dfm}


  { TfmMappedMemSender }

constructor TfmMappedMemSender.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);

  { Create and prepare the memory mapping connection }
  FMemMapping := TMemMapExample.Create;
end;

destructor TfmMappedMemSender.Destroy;
begin
  TRY
    if Assigned(FMemMapping) then
      FreeAndNil(FMemMapping);
  FINALLY
    inherited Destroy;
  END;
end;

procedure TfmMappedMemSender.btnSendPressMeClick(Sender: TObject);
var
  msOut: TMemoryStream;
begin
  { If a mapping already exists, then connect to it and transfer the data }
  if FMemMapping.OpenMappingOnly then
  begin
    msOut := TMemoryStream.Create;
    TRY
      { Stream out the components data }
      msOut.Position := 0;
      msOut.WriteComponent(btnAnotherPressMe);

      { Prepare the CopyData record }
      FMemMapping.Memory^.dwVersion := 1;
      FMemMapping.Memory^.dwSize := msOut.Size;

      msOut.Position := 0;
      Move(msOut.Memory^, FMemMapping.Memory^.Data[0], msOut.Size);
    FINALLY
      { Data should now be in the memory mapping buffer }
      FreeAndNil(msOut);
    END;
  end else
    ShowMessage('Unable to find the destination window');
end;

end.
